app.js
======

[app.js]

**wq/app.js** is an configuration-driven application controller that leverages the capabilities of [store.js] and [pages.js] to facilitate the creation of complete mobile web apps for viewing and submitting field data.  It is primarily intended for use as a client for [wq.db]'s [REST service], but can be used with any REST service with the same structure.

## Basic Usage

The basic usage of app.js is relatively straightforward:
```javascript
app.init(config, templates, [baseurl], [svcurl]);
```
where `config` is a [wq configuration object] and `templates` is a collection of [Mustache templates] for use in [client-side rendering].  The optional `baseurl` argument is used to prefix application routes in [pages.js].  It should be set to the base url of your application (without the trailing `/`) if your application is not running at the root of your domain.  The optional `svcurl` option is used to prefix REST requests in [store.js].  It should be set to the base url of your wq.db-compatible REST service if it is not running at the same base url as your application.  For best results, the application and the REST service should be running at the same URL.

### Configuration
A wq.db-compatible REST service will automatically provide a  `config.js` that can be utilized by app.js.  However, the autogenerated config.js will be missing the `defaults`, `transitions`, and `store` configuration options.  Thus, the conventional approach is to create an AMD module `js/config.js` that depends on the server-created config and adds the missing attributes.

```javascript
define(['/config.js', function(config) {
// config.pages already exists on server-generated config

config.defaults = {
//...
};
config.transitions = {
//...
}
config.store = {
//...
}
return config;
});
```

> **Note**: If you need to customize an option in the server generated `config.pages`, you should use `app.router.customize_page` in [wq.db.rest] rather than overriding it in your `config.js`.  This ensures that the client and the server are on the same "page".


If you are not utilizing the wq.db-generated configuration, you can define the entire configuration object in config.js:

```javascript
define({
    'pages': { /* ... */ },
    'defaults': { /* ... */ },
    'transitions': { /* ... */ },
    'store': { /* ... */ }
});
```

### Inlining Templates
The `templates` can be created as regular HTML files and then inlined into a JavaScript object through the [collectjson] step in the [wq build process].  The resulting object should be of the form:

```javascript
{
     '[modelname]_list': "<html>...</html>",
     '[modelname]_detail': "<html>...</html>",
     '[modelname]_edit': "<html>...</html>",
     // so on for each model...
     
     '[staticpage]': "<html>...</html>",
     'partials': {
          'head': "..."
     }
}
```
By convention, this object is typically wrapped in an AMD `define()` and placed in the file `js/template.js`.

### Putting all Together

`app.init` is typically called immediately when the JavaScript loads.  Assuming `template.js` and `config.js` are created as above, this can be accomplished by creating a main module for your application:

```javascript
// js/myapp.js
require(['wq/app', 'config', 'templates'],
function(app, config, templates) {
   app.init(config, templates);
});
```
And then configuring RequireJS to load it in your `index.html`:
```xml
<script src="js/wq/lib/require.js" data-main="js/myapp"></script>
```

If you are utilizing both wq.app and wq.db in your project you may find it useful to leverage the [Django wq template] which will up the above project layout for you.

## Advanced Configuration
WIP

## Internal API
WIP

[app.js]: https://github.com/wq/wq.app/blob/master/js/wq/app.js
[store.js]: http://wq.io/docs/store.js
[pages.js]: http://wq.io/docs/pages.js
[wq.db]: http://wq.io/wq.db
[REST service]: http://wq.io/docs/rest
[wq.db.rest]: http://wq.io/docs/rest
[wq configuration object]: http://wq.io/docs/config
[client-side rendering]: http://wq.io/docs/web-app
[Mustache templates]: http://wq.io/docs/templates
[collectjson]: http://wq.io/docs/collectjson
[wq build process]: http://wq.io/docs/build
[Django wq template]: https://github.com/wq/django-wq-template
